@@ -93,9 +93,7 @@ def _custom_json_formatter(record: dict):
     return '{custom_json}\n'
 
 
-
-## Checking logger module already exists or not:
-if os.getenv('__INIT_LOG_HANDLER__') is None:
+def _init():
     ## Loading environment variables from .env file, if it's exits:
     _env_filename = '.env'
     _current_dir = os.getcwd()
@@ -172,13 +170,13 @@ if os.getenv('__INIT_LOG_HANDLER__') is None:
 
     ## Initializing std stream log handler:
     logger.remove()
-    _log_handler_id = logger.add(_std_sink,
-                                level=_configs_dict['level'],
-                                format=_configs_dict['std_format_str'],
-                                colorize=_configs_dict['use_color'],
-                                filter=_add_lvlname,
-                                backtrace=_configs_dict['use_backtrace'],
-                                diagnose=_configs_dict['use_diagnose'])
+    logger.add(_std_sink,
+                level=_configs_dict['level'],
+                format=_configs_dict['std_format_str'],
+                colorize=_configs_dict['use_color'],
+                filter=_add_lvlname,
+                backtrace=_configs_dict['use_backtrace'],
+                diagnose=_configs_dict['use_diagnose'])
 
     _APP_NAME = str(os.getenv('APP_NAME')).strip().replace(' ', '_').lower()
     if _APP_NAME == 'none':
@@ -289,6 +287,4 @@ if os.getenv('__INIT_LOG_HANDLER__') is None:
                             backtrace=_configs_dict['use_backtrace'],
                             diagnose=_configs_dict['use_diagnose'])
 
-
-    ## Setting checkpoint environment variable for initializing logger.
-    os.environ['__INIT_LOG_HANDLER__'] = str(_log_handler_id)
+_init()
